LookAt

Struct LookAt 

pub struct LookAt {
    pub smoothness: f32,
    pub target: Point3<f32>,
    /* private fields */
}
Rotates the camera to point at a world-space position.

The target tracking can be additionally smoothed, and made to look ahead of it.

Fields

smoothness: f32

Exponential smoothing factor

target: Point3<f32>

The world-space position to look at

Implementations

Source

impl LookAt

pub fn new<P>(target: P) -> Self
where P: Into<Point3<f32>>,

pub fn tracking_smoothness(self, smoothness: f32) -> Self

Set the exponential smoothing factor for target position tracking.

pub fn tracking_predictive(self, predictive: bool) -> Self

Reverse target position smoothing, causing the camera to look ahead of it. This can then be chained with Smooth, to create a camera that smoothly follows an object, but doesn’t lag far behind it.